@@ -67,13 +67,17 @@ async def info_command(spas, args):
 async def set_command(spas, args):
     for spa in spas:
         if args.temperature:
-            await spa.set_temperature(38.3)
+            await spa.set_temperature(args.temperature)
 
         if args.light_mode:
             for light in await spa.get_lights():
-                await light.set_mode(light.LightModes[args.lights], 25)
                 if args.verbosity > 0:
                     print(light)
+                mode = light.LightMode[args.light_mode]
+                if mode == light.LightMode.OFF:
+                    await light.set_mode(mode, 0)
+                else:
+                    await light.set_mode(mode, 50)
 
 
 async def main(argv):
